@@ -19,13 +19,13 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
-#include <stdio.h>
-#include <stdlib.h>
-#include <fcntl.h>
-#include <unistd.h>
+#include "config.h"                  /* Required for HAVE_DVDCSS_DVDCSS_H */
+#include <stdio.h>                               /* fprintf */
+#include <stdlib.h>                              /* free */
+#include <fcntl.h>                               /* open */
+#include <unistd.h>                              /* lseek */
 
-#include "config.h"
-#include "dvdread/dvd_reader.h"
+#include "dvdread/dvd_reader.h"      /* DVD_VIDEO_LB_LEN */
 #include "dvd_input.h"
 
 
@@ -39,20 +39,22 @@ char *      (*dvdinput_error) (dvd_input_t);
 
 #ifdef HAVE_DVDCSS_DVDCSS_H
 /* linking to libdvdcss */
-#include <dvdcss/dvdcss.h>
-#define DVDcss_open(a) dvdcss_open((char*)(a))
-#define DVDcss_close   dvdcss_close
-#define DVDcss_seek    dvdcss_seek
-#define DVDcss_read    dvdcss_read
-#define DVDcss_error   dvdcss_error
+# include <dvdcss/dvdcss.h>
+# define DVDcss_open(a) dvdcss_open((char*)(a))
+# define DVDcss_close   dvdcss_close
+# define DVDcss_seek    dvdcss_seek
+# define DVDcss_read    dvdcss_read
+# define DVDcss_error   dvdcss_error
 #else
 
 /* dlopening libdvdcss */
-#ifdef HAVE_DLFCN_H
-#include <dlfcn.h>
-#else
+# if defined(HAVE_DLFCN_H) && !defined(USING_BUILTIN_DLFCN)
+#  include <dlfcn.h>
+# else
+# if defined(WIN32)
 /* Only needed on MINGW at the moment */
-#include "../../msvc/contrib/dlfcn.c"
+#  include "../msvc/contrib/dlfcn.c"
+# endif
 #endif
 
 typedef struct dvdcss_s *dvdcss_t;
@@ -82,7 +84,7 @@ static dvd_input_t css_open(const char *target)
   dvd_input_t dev;
 
   /* Allocate the handle structure */
-  dev = (dvd_input_t) malloc(sizeof(*dev));
+  dev = malloc(sizeof(*dev));
   if(dev == NULL) {
     fprintf(stderr, "libdvdread: Could not allocate memory.\n");
     return NULL;
@@ -157,7 +159,7 @@ static dvd_input_t file_open(const char *target)
   dvd_input_t dev;
 
   /* Allocate the library structure */
-  dev = (dvd_input_t) malloc(sizeof(*dev));
+  dev = malloc(sizeof(*dev));
   if(dev == NULL) {
     fprintf(stderr, "libdvdread: Could not allocate memory.\n");
     return NULL;
