@@ -16,6 +16,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
+#include "config.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <unistd.h>
@@ -149,7 +150,7 @@ static void ifo_print_video_attributes(int level, video_attr_t *attr) {
   }
 
   printf("U%x, ", attr->unknown1);
-  assert(!attr->unknown1);
+  /* assert(!attr->unknown1); */
 
   if(attr->line21_cc_1 || attr->line21_cc_2) {
     printf("NTSC CC ");
@@ -267,7 +268,8 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
   switch(attr->lang_type) {
   case 0:
     // not specified
-    assert(attr->lang_code == 0 || attr->lang_code == 0xffff);
+    if(attr->lang_code != 0 && attr->lang_code != 0xffff)
+        printf("Lang_code 0x%x, please send a bug report!", attr->lang_code);
     break;
   case 1:
     printf("%c%c ", attr->lang_code>>8, attr->lang_code & 0xff);
@@ -342,8 +344,8 @@ static void ifo_print_audio_attributes(int level, audio_attr_t *attr) {
     printf("(please send a bug report) ");
   }
 
-  printf("%d ", attr->unknown1);
-  printf("%d ", attr->unknown3);
+  printf("Unknown1: %d ", attr->unknown1);
+  printf("Unknown3: %d ", attr->unknown3);
 }
 
 static void ifo_print_subp_attributes(int level, subp_attr_t *attr) {
@@ -1189,7 +1191,7 @@ void ifo_print(dvd_reader_t *dvd, int title) {
     if(ifohandle->menu_vobu_admap) {
       ifoPrint_VOBU_ADMAP(ifohandle->menu_vobu_admap);
     } else {
-      printf("No Menu VOBU Address map present\n");
+      printf("No Menu VOBU address map present\n");
     }
 
     printf("\nCell Address table\n");
